==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/config_wizard/translations/config_wizard_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Impostazione account&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation>Rete IM</translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation>Impostare un account esistente</translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation>Creare nuovo account</translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation>Non settare il mio account adesso</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configurazione guidata completata&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation>Vai ad Impostazione Account dopo aver chiuso questa finestra</translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWizardConfigurationUiHandler</name>
    <message>
        <source>Start Configuration Wizard...</source>
        <translation>Inizia Configurazione Guidata</translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Benvenuto in Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;Questa procedura guidata ti aiuterà a configurare le impostazioni di base di Kadu&lt;/p&gt;&lt;p&gt;Si prega di scegliere la lingua preferita e creare un nickname&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation>Impostazione profilo</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Lingua</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Nickname</translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Impostazione Account&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Configurazione guidata Kadu</translation>
    </message>
</context>
</TS>

==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/config_wizard/translations/config_wizard_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Impostazione account&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation>Rete IM</translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation>Impostare un account esistente</translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation>Creare nuovo account</translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation>Non settare il mio account adesso</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configurazione guidata completata&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation>Vai ad Impostazione Account dopo aver chiuso questa finestra</translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConfigWizardConfigurationUiHandler</name>
    <message>
        <source>Start Configuration Wizard</source>
        <translation>Inizia Configurazione Guidata</translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Benvenuto in Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;Questa procedura guidata ti aiuterà a configurare le impostazioni di base di Kadu&lt;/p&gt;&lt;p&gt;Si prega di scegliere la lingua preferita e creare un nickname&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation>Impostazione profilo</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Lingua</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Nickname</translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Impostazione Account&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Configurazione guidata Kadu</translation>
    </message>
</context>
</TS>
